#ifndef __GURUMDDS_XML_H__
#define __GURUMDDS_XML_H__

#include <gurumdds/dcps.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Create DDS XML Application Context
 *
 * @param dpf domain participant factory
 * @param xml_path Paths of xml or NULL if you want to load xml from environment variable
 *                 note that paths can be separated by colon
 * @param name_expr application name expression (e.g. ShapesRelatedApplications::SimpleShapesDemoApplication)
 *
 * @return List of domain participants in the application
 */
GURUMDDS_C_DLLAPI dds_InstanceHandleSeq* dds_xml_Application_create(dds_DomainParticipantFactory* dpf, const char* xml_path, const char* name_expr);

/**
 * Retrieves the value of DomainParticipant QoS policies from the QoS Profile in DDS XML
 *
 * @param dpf domain participant factory
 * @param xml_path Paths of xml or NULL if you want to load xml from environment variable
 *                 note that paths can be separated by colon
 * @param name_expr qos profile name expression (e.g. DefaultQosProfile::PubSubBase)
 * @param qos domain participant qos
 *
 * @return standard retrun code
 */
GURUMDDS_C_DLLAPI dds_ReturnCode_t dds_xml_QosProfile_get_participant_qos(dds_DomainParticipantFactory* dpf, const char* xml_path, const char* name_expr, dds_DomainParticipantQos* qos);

/** @see dds_xml_QosProfile_get_participant_qos */
GURUMDDS_C_DLLAPI dds_ReturnCode_t dds_xml_QosProfile_get_topic_qos(dds_DomainParticipantFactory* dpf, const char* xml_path, const char* name_expr, dds_TopicQos* qos);

/** @see dds_xml_QosProfile_get_participant_qos */
GURUMDDS_C_DLLAPI dds_ReturnCode_t dds_xml_QosProfile_get_publisher_qos(dds_DomainParticipantFactory* dpf, const char* xml_path, const char* name_expr, dds_PublisherQos* qos);

/** @see dds_xml_QosProfile_get_participant_qos */
GURUMDDS_C_DLLAPI dds_ReturnCode_t dds_xml_QosProfile_get_subscriber_qos(dds_DomainParticipantFactory* dpf, const char* xml_path, const char* name_expr, dds_SubscriberQos* qos);

/** @see dds_xml_QosProfile_get_participant_qos */
GURUMDDS_C_DLLAPI dds_ReturnCode_t dds_xml_QosProfile_get_datawriter_qos(dds_DomainParticipantFactory* dpf, const char* xml_path, const char* name_expr, dds_DataWriterQos* qos);

/** @see dds_xml_QosProfile_get_participant_qos */
GURUMDDS_C_DLLAPI dds_ReturnCode_t dds_xml_QosProfile_get_datareader_qos(dds_DomainParticipantFactory* dpf, const char* xml_path, const char* name_expr, dds_DataReaderQos* qos);

/**
 * API for web_enabled_dds
 */
GURUMDDS_C_DLLAPI dds_Topic* dds_xml_create_topic(dds_DomainParticipant* participant, const char* topic_xml_expr, const char* qos_lib_xml_expr);
GURUMDDS_C_DLLAPI dds_ReturnCode_t dds_xml_register_type(dds_DomainParticipant* participant, const char* register_type_xml_expr, const char* types_xml_expr);
GURUMDDS_C_DLLAPI dds_DataWriter* dds_xml_create_datawriter(dds_Publisher* publisher, const char* dw_xml_expr, const char* qos_lib_xml_expr);
GURUMDDS_C_DLLAPI dds_DataReader* dds_xml_create_datareader(dds_Subscriber* subscriber, const char* dr_xml_expr, const char* qos_lib_xml_expr);
GURUMDDS_C_DLLAPI dds_Publisher* dds_xml_create_publisher(dds_DomainParticipant* participant, const char* pub_xml_expr, const char* qos_lib_xml_expr);
GURUMDDS_C_DLLAPI dds_Subscriber* dds_xml_create_subscriber(dds_DomainParticipant* participant, const char* sub_xml_expr, const char* qos_lib_xml_expr);
GURUMDDS_C_DLLAPI dds_DomainParticipant* dds_xml_create_participant(const char* dp_xml_expr, const char* types_xml_expr, const char* domain_lib_xml_expr, const char* dp_lib_xml_expr, const char* qos_lib_xml_expr);

#ifdef __cplusplus
}
#endif

#endif /* __GURUMDDS_XML_H__ */
